@@ -60,7 +60,7 @@ class CfnBudget(
             notifications_with_subscribers=notifications_with_subscribers,
         )
 
-        jsii.create(CfnBudget, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -891,7 +891,7 @@ class CfnBudgetsAction(
             subscribers=subscribers,
         )
 
-        jsii.create(CfnBudgetsAction, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
